/**
 * Search `tree` for a heading matching `test` and change its “section” with
 * `handler`.
 *
 * A “section” ranges from the matched heading until the next heading of the
 * same or lower depth, or the end of the document.
 *
 * If `ignoreFinalDefinitions: true`, final definitions “in” the section are
 * excluded.
 *
 * @param {Node} tree
 *   Tree to change.
 * @param {Test | Options} options
 *   Configuration.
 * @param {Handler} handler
 *   Handle a section.
 * @returns {void}
 *   Nothing.
 */
export function headingRange(
  tree: Node,
  options: Test | Options,
  handler: Handler
): void
export type UnistParent = import('unist').Parent
export type Content = import('mdast').Content
export type Heading = import('mdast').Heading
export type Root = import('mdast').Root
export type Node = Content | Root
export type Parent = Extract<Node, UnistParent>
/**
 * Check if a node matches.
 */
export type TestFunction = (
  value: string,
  node: Heading
) => boolean | null | undefined
/**
 * Test for a heading.
 *
 * When `string`, wrapped in `new RegExp('^(' + value + ')$', 'i')`;
 * when `RegExp`, wrapped in `(value) => expression.test(value)`
 */
export type Test = string | RegExp | TestFunction
/**
 * Configuration.
 */
export type Options = {
  /**
   *   Test for a heading.
   */
  test: Test
  /**
   * Ignore final definitions otherwise in the section.
   */
  ignoreFinalDefinitions?: boolean | null | undefined
}
/**
 * Extra info.
 */
export type Info = {
  /**
   *   Parent of the section.
   */
  parent: Parent
  /**
   *   Index of `start` in `parent`.
   */
  start: number
  /**
   *   Index of `end` in `parent`.
   */
  end: number | null
}
/**
 * Callback called when a section is found.
 */
export type Handler = (
  start: Heading,
  between: Array<Node>,
  end: Node | undefined,
  scope: Info
) => Array<Node | null | undefined> | null | undefined | void
